# Synchronizing Process Variants
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/synchronizing-process-variants#introduction)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/synchronizing-process-variants#prerequisites)
  * [Enabling Process Variants Import](https://help.sap.com/docs/leanix/ea/synchronizing-process-variants#enabling-process-variants-import)
  * [Aggregation of Process Template and Variants](https://help.sap.com/docs/leanix/ea/synchronizing-process-variants#aggregation-of-process-template-and-variants)
  * [Synchronizing Application and Organizational Fact Sheets](https://help.sap.com/docs/leanix/ea/synchronizing-process-variants#synchronizing-application-and-organizational-fact-sheets)
  * [Visualizing Relations](https://help.sap.com/docs/leanix/ea/synchronizing-process-variants#visualizing-relations)
  * [Synchronizing Other Fact Sheets](https://help.sap.com/docs/leanix/ea/synchronizing-process-variants#synchronizing-other-fact-sheets)
  * [Synchronizing Hierarchy and Process Relations](https://help.sap.com/docs/leanix/ea/synchronizing-process-variants#synchronizing-hierarchy-and-process-relations)
  * [Handling of Process Variant Dimensions](https://help.sap.com/docs/leanix/ea/synchronizing-process-variants#handling-of-process-variant-dimensions)


This guide explains how SAP Signavio process variants are synchronized and represented in SAP LeanIX.
